@@ -1,9 +1,12 @@
 package Gitalist::Model::GitRepos;
 
 use Moose;
-use Gitalist::Git::Repo;
+use Gitalist::Git::CollectionOfRepositories::FromDirectory;
+use Gitalist::Git::CollectionOfRepositories::FromListOfDirectories;
+use MooseX::Types::Moose qw/Maybe ArrayRef/;
 use MooseX::Types::Common::String qw/NonEmptySimpleStr/;
 use Moose::Util::TypeConstraints;
+use Moose::Autobox;
 use namespace::autoclean;
 
 extends 'Catalyst::Model';
@@ -14,6 +17,14 @@ my $repo_dir_t = subtype NonEmptySimpleStr,
     where { -d $_ },
     message { 'Cannot find repository dir: "' . $_ . '", please set up gitalist.conf, or set GITALIST_REPO_DIR environment or pass the --repo_dir parameter when starting the application' };
 
+my $arrayof_repos_dir_t = subtype ArrayRef[$repo_dir_t],
+    where { 1 },
+    message { 'Cannot find repository directories listed in config - these are invalid directories: ' . join(', ', $_->flatten) };
+
+coerce $arrayof_repos_dir_t,
+    from NonEmptySimpleStr,
+    via { [ $_ ] };
+
 has config_repo_dir => (
     isa => NonEmptySimpleStr,
     is => 'ro',
@@ -27,6 +38,17 @@ has repo_dir => (
     lazy_build => 1
 );
 
+has repos => (
+    isa => $arrayof_repos_dir_t,
+    is => 'ro',
+    default => sub { [] },
+    traits => ['Array'],
+    handles => {
+        _repos_count => 'count',
+    },
+    coerce => 1,
+);
+
 sub _build_repo_dir {
     my $self = shift;
     $ENV{GITALIST_REPO_DIR} ?
@@ -38,14 +60,19 @@ sub _build_repo_dir {
 
 after BUILD => sub {
     my $self = shift;
-    $self->repo_dir; # Explode loudly at app startup time if there is no repos
-                     # dir, rather than on first hit
+    # Explode loudly at app startup time if there is no list of
+    # repositories or repos dir, rather than on first hit
+    $self->_repos_count || $self->repo_dir;
 };
 
 sub build_per_context_instance {
     my ($self, $app) = @_;
-
-    Gitalist::Git::Repo->new(repo_dir => $self->repo_dir);
+    if ($self->_repos_count) {
+        Gitalist::Git::CollectionOfRepositories::FromListOfDirectories->new(repos => $self->repos);
+    }
+    else {
+        Gitalist::Git::CollectionOfRepositories::FromDirectory->new(repo_dir => $self->repo_dir);
+    }
 }
 
 __PACKAGE__->meta->make_immutable;
