@@ -1,6 +1,4 @@
 #!/usr/bin/env perl
-use FindBin;
-BEGIN { do "$FindBin::Bin/env" or die $@ }
 
 BEGIN {
     $ENV{CATALYST_SCRIPT_GEN} = 40;
